"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("../common");
const filesystem_1 = require("./filesystem");
class CollectionPopulator {
    constructor(extensions) {
        if (extensions.length === 0) {
            throw new Error('Array of supported extensions must not be empty');
        }
        this.extensions = extensions;
    }
    readFromPath(path) {
        const subdirectories = filesystem_1.fileSystem.listValidDirectories(path);
        return this.readCollections(subdirectories, path);
    }
    readCollections(directories, inputDirectory) {
        return directories.reduce((collections, directoryName) => {
            const relativePath = `${inputDirectory}/${directoryName}`;
            const collection = this.readCollection(relativePath, directoryName);
            if (collection) {
                collections.push(collection);
            }
            return collections;
        }, []);
    }
    readCollection(path, directoryName) {
        const name = this.getCollectionName(directoryName);
        const documents = this.populateDocumentsContent(path);
        if (!documents) {
            return null;
        }
        return {
            name,
            documents,
        };
    }
    populateDocumentsContent(collectionPath) {
        const fileNames = filesystem_1.fileSystem.listFileNames(collectionPath);
        if (fileNames.length === 0) {
            common_1.log(`Directory '${collectionPath}' is empty. Skipping...`);
            return;
        }
        const documentFileNames = filesystem_1.fileSystem.filterSupportedDocumentFileNames(fileNames, this.extensions);
        if (documentFileNames.length === 0) {
            common_1.log(`No supported files found in directory '${collectionPath}'. Skipping...`);
            return;
        }
        const documentPaths = documentFileNames.map(fileName => `${collectionPath}/${fileName}`);
        return filesystem_1.fileSystem.readFilesContent(documentPaths);
    }
    getCollectionName(directoryName) {
        const separators = /\s*[-_\.\s]\s*/;
        let collectionName;
        if (directoryName.match(separators)) {
            collectionName = directoryName.split(separators)[1];
        }
        else {
            collectionName = directoryName;
        }
        return collectionName;
    }
}
exports.CollectionPopulator = CollectionPopulator;
//# sourceMappingURL=index.js.map